@@ -1,5 +1,6 @@
 import re
 from os import path
+from sys import stderr
 
 from lxml.html import HtmlElement
 
@@ -27,6 +28,7 @@ class Base:
         }
         self._params = {
             'destination': 'Manga',
+            'cf-protect': False,
         }
         self._image_params = {
             'crop': (0, 0, 0, 0),
@@ -47,9 +49,13 @@ class Base:
 
     @property
     def domain(self) -> str:
-        if not self._storage.get('domain_uri', None):
-            self._storage['domain_uri'] = re.search('(https?://[^/]+)', self._params['url']).group(1)
-        return self._storage.get('domain_uri', '')
+        try:
+            if not self._storage.get('domain_uri', None):
+                self._storage['domain_uri'] = re.search('(https?://[^/]+)', self._params['url']).group(1)
+            return self._storage.get('domain_uri', '')
+        except Exception:
+            print('url is broken!', file=stderr)
+            exit()
 
     @staticmethod
     def image_auto_crop(src_path, dest_path=None):
@@ -63,15 +69,19 @@ class Base:
             image.crop_manual_with_offsets(offsets=self._image_params['crop'], dest_path=dest_path)
             image.close()
 
-    def http(self, new=False) -> Http:
-        http_params = {
-            'allow_webp': not self._params.get('disallow_webp', None),
-            'referer': self._storage.get('referer', self.domain),
-            'user_agent': self._get_user_agent(),
-            'proxies': self._storage.get('proxies', None),
-            'cookies': self._storage.get('cookies', None),
-            'kwargs': self._http_kwargs
-        }
+    def _build_http_params(self, params):
+        if params is None:
+            params = {}
+        params.setdefault('allow_webp', not self._params.get('disallow_webp', None))
+        params.setdefault('referer', self._storage.get('referer', self.domain))
+        params.setdefault('user_agent', self._get_user_agent())
+        params.setdefault('proxies', self._storage.get('proxies', None))
+        params.setdefault('cookies', self._storage.get('cookies', None))
+        params.setdefault('kwargs', self._http_kwargs)
+        return params
+
+    def http(self, new=False, params=None) -> Http:
+        http_params = self._build_http_params(params)
         if new:
             http = Http(**http_params)
             return http
@@ -166,3 +176,10 @@ class Base:
         if self._params['rename_pages']:
             _path = '{:0>3}'.format(idx)
         return _path + extension
+
+    def chapter_for_json(self) -> str:
+        return self.chapter
+
+    def put_info_json(self, meta):
+        # manga_name, url, directory
+        pass
