@@ -94,6 +94,7 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
                 self._storage['files'] = self.get_files()
                 self.loop_files()
             except Exception as e:
+                print(e, file=stderr)
                 self._info.set_last_volume_error(e)
 
     def loop_chapters(self):
@@ -108,7 +109,10 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
             self._download_chapter(idx, _min, _max)
 
     def loop_files(self):
-        if isinstance(self._storage['files'], list) and len(self._storage['files']) > 0:
+        if isinstance(self._storage['files'], list):
+            if len(self._storage['files']) == 0:
+                print('Error processing file: %s' % self.get_archive_name(), file=stderr)
+                return
             self._archive = Archive()
             self._archive.not_change_files_extension = self._params.get('not_change_files_extension', False)
             self._archive.no_webp = self._image_params.get('no_webp', False)
@@ -137,7 +141,7 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
         _path, idx, _url = self._save_file_params_helper(url, idx)
 
         if not is_file(_path) or file_size(_path) < 32:
-            self.http().download_file(_url, _path)
+            self.http().download_file(_url, _path, idx)
         self.after_file_save(_path, idx)
         self._archive.add_file(_path)
 
