@@ -2,8 +2,11 @@ import re
 
 providers_list = {
     '3asq_info': [
-        r'3asq\.info/',
+        r'3asq\.info/.',
     ],
+    # '8muses_com': [
+    #     r'8muses\.com/comics/album/.',
+    # ],
     'ac_qq_com': [
         r'ac\.qq\.com/Comic.+?/id/\d',
     ],
@@ -23,10 +26,10 @@ providers_list = {
         r'antisensescans\.com/online/(series|read)/.',
     ],
     'asmhentai_com': [
-        r'asmhentai\.com/(g|gallery)/\d'
+        r'asmhentai\.com/(g|gallery)/\d',
     ],
     'atfbooru_ninja': [
-        r'atfbooru.ninja/posts.',
+        r'atfbooru\.ninja/posts.',
     ],
     'authrone_com': [
         r'authrone\.com/manga/.',
@@ -83,6 +86,9 @@ providers_list = {
     'desu_me': [
         r'desu\.me/manga/.',
     ],
+    'digitalteam1_altervista_org': [
+        r'digitalteam1\.altervista\.org/reader/read/.',
+    ],
     # 'dm5_com': [
     #     r'dm5\.com/manhua-.',
     # ],
@@ -93,15 +99,18 @@ providers_list = {
     'e_hentai_org': [
         r'e-hentai\.org/g/\d',
     ],
-    '8muses_com': [
-        r'8muses\.com/comics/album/.',
+    'exhentai_org': [
+        r'exhentai\.org/g/\d',
     ],
     'fanfox_net': [
-        r'fanfox.net/manga/.',
+        r'fanfox\.net/manga/.',
     ],
     'freeadultcomix_com': [
         r'freeadultcomix\.com/.',
     ],
+    'freemanga_to': [
+        r'freemanga\.to/(manga|chapter)/.',
+    ],
     'funmanga_com': [
         r'funmanga\.com/.',
     ],
@@ -125,12 +134,15 @@ providers_list = {
         r'hakihome\.com/.',
     ],
     'hatigarmscans_eu': [
-        r'hatigarmscans.eu/hs/(series|read)',
-        r'hatigarmscans.net/hs/(series|read)',
+        r'hatigarmscans\.eu/hs/(series|read).',
+        r'hatigarmscans\.net/hs/(series|read).',
+        r'hatigarmscans\.net/manga/.',
     ],
     'heavenmanga_biz': [
         r'heavenmanga\.site/.',
         r'heavenmanga\.world/.',
+        r'heavenmanga\.life/.',
+        r'heavenmanga\.biz/.',
     ],
     'hentai2read_com': [
         r'hentai2read\.com/.',
@@ -142,7 +154,7 @@ providers_list = {
         r'hentai-chan\.me/(related|manga|online)/.',  # todo
     ],
     'hentai_image_com': [
-        r'hentai-image.com/image/.',
+        r'hentai-image\.com/image/.',
     ],
     'hentaifox_com': [
         r'hentaifox\.com/.',
@@ -156,6 +168,9 @@ providers_list = {
     'hitomi_la': [
         r'hitomi\.la/(galleries|reader)/.',
     ],
+    'hgamecg_com': [
+        r'hgamecg\.com/index/category/\d',
+    ],
     'hitmanga_eu': [
         r'hitmanga\.eu/.',
         r'mymanga\.io/.',
@@ -163,14 +178,21 @@ providers_list = {
     'hocvientruyentranh_com': [
         r'hocvientruyentranh\.com/(manga|chapter)/.',
     ],
+    'hoducomics_com': [
+        r'hoducomics\.com/webtoon/list/\d',
+        r'hodu1\.com/webtoon/list/\d',
+    ],
     'hotchocolatescans_com': [
         r'hotchocolatescans\.com/fs/(series|read)/.',
         r'mangaichiscans\.mokkori\.fr/fs/(series|read)/.',
-        r'taptaptaptaptap.net/fs/(series|read)/.',
+        r'taptaptaptaptap\.net/fs/(series|read)/.',
     ],
     'riceballicious_info': [
         r'riceballicious\.info/fs/reader/(series|read)/.',
     ],
+    'rocaca_com': [
+        r'rocaca\.com/manga/.',
+    ],
     'inmanga_com': [
         r'inmanga\.com/ver/manga/.',
     ],
@@ -221,21 +243,30 @@ providers_list = {
     ],
     'lolibooru_moe': [
         r'lolibooru\.moe/post.',
-        r'yande\.re/post.',
     ],
     'lolivault_net': [
-        r'lolivault.net/online/(series|read)',
+        r'lolivault\.net/online/(series|read).',
     ],
     'luscious_net': [
-        r'luscious\.net/c/incest_manga/pictures/.', r'luscious\.net/albums/.',
+        r'luscious\.net/.+/album/.',
+        r'luscious\.net/albums/.',
+    ],
+    'mangapark_org': [
+        r'mangapark\.org/(series|chapter)/',   # is different!
+    ],
+    'mang_as': [
+        r'mang\.as/manga/.',
     ],
     'manga_ae': [
         r'manga\.ae/.',
     ],
     'manga_fox_com': [
-        r'manga-fox.com/.',
+        r'manga-fox\.com/.',
         r'manga-here\.io/.',
     ],
+    'manga_mexat_com': [
+        r'manga\.mexat\.com/category/.',
+    ],
     'manga_online_biz': [
         r'manga-online\.biz/.',
     ],
@@ -266,7 +297,7 @@ providers_list = {
     ],
     'mangachan_me_download': [
         r'mangachan\.me/download/.',
-        r'hentai-chan.me/download/.',
+        r'hentai-chan\.me/download/.',
         r'yaoichan\.me/download/.',
     ],
     'mangacanblog_com': [
@@ -281,6 +312,7 @@ providers_list = {
     ],
     'mangadex_com': [
         r'mangadex\.com/(manga|chapter)/.',
+        r'mangadex\.org/(manga|chapter)/.',
     ],
     'mangaeden_com': [
         r'mangaeden\.com/[^/]+/[^/]+-manga/.',
@@ -290,15 +322,21 @@ providers_list = {
         r'mangaforall\.com/m/.',
     ],
     'mangafreak_net_download': [
-        r'mangafreak\.net/Manga/',
+        r'mangafreak\.net/Manga/.',
     ],
     'mangago_me': [
         r'mangago\.me/read-manga/.',
     ],
+    'mangahasu_se': [
+        r'mangahasu\.se/.',
+    ],
     'mangahere_cc': [
         r'mangahere\.co/manga/.',
         r'mangahere\.cc/manga/.',
     ],
+    'mangahi_net': [
+        r'mangahi\.net/.',
+    ],
     'mangahome_com': [
         r'mangahome\.com/manga/.',
     ],
@@ -323,6 +361,9 @@ providers_list = {
     'mangakakalot_com': [
         r'mangakakalot\.com/(manga|chapter)/.',
     ],
+    'mangakatana_com': [
+        r'mangakatana\.com/manga/.',
+    ],
     'mangaku_web_id': [
         r'mangaku\.web\.id/.',
     ],
@@ -332,7 +373,14 @@ providers_list = {
     'mangalife_us': [
         r'mangalife\.us/(read-online|manga)/.',
     ],
+    'mangamew_com': [
+        r'mangamew\.com/(\w+-)?manga/.',
+    ],
+    'mangamew_com_vn': [
+        r'mangamew\.com/(\w+-)?truyen/.',
+    ],
     'manganelo_com': [
+        r'mangabat\.com/(manga|chapter)/.',
         r'manganelo\.com/(manga|chapter)/.',
     ],
     'mangaon_net': [
@@ -356,6 +404,12 @@ providers_list = {
     'mangareader_net': [
         r'mangareader\.net/.',
     ],
+    'mangareader_xyz': [
+        r'mangareader\.xyz/manga/.',
+        r'mangareader\.xyz/.+?/chapter-\d',
+        r'mangafox\.cc/manga/.',
+        r'mangafox\.cc/.+?/chapter-\d',
+    ],
     'mangarock_com': [
         r'mangarock\.com/manga/.',
     ],
@@ -369,14 +423,15 @@ providers_list = {
         r'mangaseeonline\.us/(read-online|manga)/.',
     ],
     'mangashiro_net': [
-        r'mangashiro.net/.',
+        r'mangashiro\.net/.',
     ],
     'mangasupa_com': [
         r'mangasupa\.com/(manga|chapter)/.',
     ],
     'mangatail_com': [
-        r'mangatail.me/(manga|chapter|node|content)/.',
-        r'mangasail.com/(manga|chapter|node|content)/.',
+        r'mangasail\.com/(manga|chapter|node|content)/.',
+        r'mangasail\.co/(manga|chapter|node|content)/.',
+        r'mangatail\.me/(manga|chapter|node|content)/.',
     ],
     'mangatown_com': [
         r'mangatown\.com/manga/.',
@@ -385,6 +440,12 @@ providers_list = {
         r'mangatrue\.com/manga/.',
         r'mangaall\.com/manga/.',
     ],
+    'mangawindow_net': [
+        r'mangawindow\.net/(series|chapter)/\d',  # is different!
+    ],
+    'mangax_net': [
+        r'mangax\.net/\w/.',
+    ],
     'manhuagui_com': [
         r'manhuagui\.com/comic/\d',
     ],
@@ -407,6 +468,9 @@ providers_list = {
         r'mangadoom\.co/.',
         r'mngdoom\.com/.',
     ],
+    'mymangalist_org': [
+        r'mymangalist.org/(read|chapter)-',
+    ],
     'myreadingmanga_info': [
         r'myreadingmanga\.info/.',
     ],
@@ -416,6 +480,9 @@ providers_list = {
     'nhentai_net': [
         r'nhentai\.net/g/.',
     ],
+    'niadd_com': [
+        r'niadd\.com/manga/.',
+    ],
     'nightow_net': [
         r'nightow\.net/online/\?manga=.',
     ],
@@ -427,8 +494,8 @@ providers_list = {
         r'noranofansub\.com(/lector)?/(series/|read/)?.',
     ],
     'nozominofansub_com': [  # mangazuki_co
-        r'nozominofansub\.com/public(/index.php)?/manga/.',
-        r'godsrealmscan\.com/public(/index.php)?/manga/.',
+        r'nozominofansub\.com/public(/index\.php)?/manga/.',
+        r'godsrealmscan\.com/public(/index\.php)?/manga/.',
     ],
     'otakusmash_com': [
         r'otakusmash\.com/.',
@@ -446,10 +513,10 @@ providers_list = {
         r'pecintakomik\.com/.',
     ],
     'plus_comico_jp_manga': [
-        r'plus\.comico\.jp/manga/\d+/',
+        r'plus\.comico\.jp/manga/\d',
     ],
     'plus_comico_jp': [
-        r'plus\.comico\.jp/store/\d+/',
+        r'plus\.comico\.jp/store/\d',
     ],
     'porncomix_info': [
         r'porncomix\.info/.',
@@ -476,15 +543,15 @@ providers_list = {
         r'rawdevart\.com/manga/.',
     ],
     'rawlh_com': [
-        r'rawlh\.com/(truyen|manga|read)-.',
-        r'rawqq.com/(truyen|manga|read)-.',
-        r'rawqv.com/(truyen|manga|read)-.',
+        r'lhscan\.net/(truyen|manga|read)-.',
+        r'rawqq\.com/(truyen|manga|read)-.',
+        r'rawqv\.com/(truyen|manga|read)-.',
     ],
     'rawneko_com': [
         r'rawneko\.com/manga/.',
     ],
     'read_egscans_com': [
-        r'read.egscans.com/.',
+        r'read\.egscans\.com/.',
     ],
     'read_powermanga_org': [
         r'lector\.dangolinenofansub\.com/(series|read)/.',
@@ -571,15 +638,15 @@ providers_list = {
     ],
     'subapics_com': [
         r'subapics\.com/manga/.',
-        r'subapics\.com/.+-chapter-',
+        r'subapics\.com/.+-chapter-.',
         r'mangakita\.net/manga/.',
-        r'mangakita\.net/.+-chapter-',
+        r'mangakita\.net/.+-chapter-.',
         r'komikstation\.com/manga/.',
-        r'komikstation\.com/.+-chapter-',
+        r'komikstation\.com/.+-chapter-.',
         r'mangavy\.com/manga/.',
-        r'mangavy\.com/.+-chapter-',
-        r'mangakid\.net/manga/',
-        r'mangakid\.net/.+-chapter-',
+        r'mangavy\.com/.+-chapter-.',
+        r'mangakid\.net/manga/.',
+        r'mangakid\.net/.+-chapter-.',
     ],
     'submanga_online': [
         r'submanga\.online/manga/.',
@@ -591,8 +658,8 @@ providers_list = {
         r'taadd\.com/(book|chapter)/.',
     ],
     'tapas_io': [
-        r'tapas.io/episode/\d',
-        r'tapas.io/series/\w',
+        r'tapas\.io/episode/\d',
+        r'tapas\.io/series/\w',
     ],
     'tenmanga_com': [
         r'tenmanga\.com/(book|chapter)/.',
@@ -604,7 +671,7 @@ providers_list = {
         r'trashscanlations\.com/series/.',
     ],
     'tonarinoyj_jp': [
-        r'tonarinoyj.jp/episode/.',
+        r'tonarinoyj\.jp/episode/.',
     ],
     'toonkor_co': [
         r'toonkor\.co/.',
@@ -623,11 +690,11 @@ providers_list = {
         r'nettruyen\.com/truyen-tranh/.',
     ],
     'truyentranhtuan_com': [
-        r'truyentranhtuan.com/.',
+        r'truyentranhtuan\.com/.',
     ],
     'tsumino_com': [
-        r'tsumino.com/Book/Info/\d',
-        r'tsumino.com/Read/View/\d',
+        r'tsumino\.com/Book/Info/\d',
+        r'tsumino\.com/Read/View/\d',
     ],
     'tumangaonline_com': [
         r'tumangaonline\.com/.',
@@ -647,10 +714,10 @@ providers_list = {
         r'webtoon\.bamtoki\.se/.',
     ],
     'webtoons_com': [
-        r'webtoons\.com/[^/]+/[^/]+/[^/]+',
+        r'webtoons\.com/[^/]+/[^/]+/.',
     ],
     'webtoontr_com': [
-        r'webtoontr.com/_/.',
+        r'webtoontr\.com/_/.',
     ],
     'westmanga_info': [
         r'westmanga\.info/.',
@@ -664,6 +731,9 @@ providers_list = {
     'wmanga_ru': [
         r'wmanga\.ru/starter/manga_.',
     ],
+    'yande_re': [
+        r'yande\.re/post.',
+    ],
     'zeroscans_com': [
         r'zeroscans\.com/manga/.',
     ],
@@ -673,20 +743,16 @@ providers_list = {
     'zip_read_com': [
         r'zip-read\.com/.',
     ],
+    'zmanga_net': [
+        r'zmanga\.net/.',
+    ],
 }
 
 
 def __check_provider(provider, url):
-    try:
-        reg = '(?:' + '|'.join(provider) + ')'
-        return re.search(reg, url)
-    except Exception as e:
-        print(reg)
-        print(type(reg))
-        print(provider, url)
-        print(type(provider), type(url))
-        print(e)
-        exit()
+    items = [r'\b' + i for i in provider]
+    reg = '(?:' + '|'.join(items) + ')'
+    return re.search(reg, url)
 
 
 def get_provider(url):
