@@ -5,6 +5,7 @@ from .helpers.std import Std
 
 class AcQqCom(Provider, Std):
     _decoder = None
+    _re = None
 
     def get_archive_name(self) -> str:
         return self.normal_arc_name(self.get_chapter_index())
@@ -26,13 +27,16 @@ class AcQqCom(Provider, Std):
         return self._elements('.chapter-page-all li a')[::-1]
 
     def get_files(self):
-        data = self._decoder.decode()
+        content = self.http_get(self.chapter)
+        data = self._re.search(content).group(1)
+        data = self._decoder.decode(data)
         return [i.get('url') for i in data.get('picture', [])][0:1]
 
     def get_cover(self) -> str:
         return self._cover_from_content('.works-cover img')
 
     def prepare_cookies(self):
+        self._re = self.re.compile(r'var\s+DATA\s*=\s*[\'"](.*?)[\'"]')
         self._decoder = AcQqComCrypt(self)
         self._base_cookies()
 
