@@ -29,5 +29,8 @@ class ChoChoxCom(Provider, Std):
         # todo meta
         pass
 
+    def chapter_for_json(self):
+        return self.get_url()
+
 
 main = ChoChoxCom
