@@ -50,8 +50,10 @@ class Std:
     def _get_content(self, selector) -> str:
         return self.http_get(selector.format(self.domain, self.manga_name))
 
-    def _base_cookies(self):
-        cookies = self.http().get_base_cookies(self.get_url())
+    def _base_cookies(self, url=None):
+        if url is None:
+            url = self.get_url()
+        cookies = self.http().get_base_cookies(url)
         self._storage['cookies'] = cookies.get_dict()
 
     def parse_background(self, image) -> str:
@@ -76,11 +78,11 @@ class Std:
     def normal_arc_name(self, idx):
         fmt = 'vol_{:0>3}'
         if not isinstance(idx, list):
-            idx = list(idx)
+            idx = [idx]
         if len(idx) > 1:
             fmt += '-{}' * (len(idx) - 1)
         elif self._zero_fill:
-            idx.append(0)
+            idx.append('0')
             fmt += '-{}'
         return fmt.format(*idx)
 
